FeatureRoute class

A discovered feature that maps to a go_router route.

Constructors

FeatureRoute({required String routeName, required String className, required String importPath})
const

Properties

className String
The view widget class, e.g. ProductView.
final
hashCode int
The hash code for this object.
no setterinherited
importPath String
Package import for the view, e.g. package:app/presentation/product/views/product_view.dart.
final
isHome bool
home is rendered as the root path and not duplicated as a constant.
no setter
routeName String
Route/constant name in camelCase, e.g. product, userProfile.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited