isHome property
bool
get
isHome
home is rendered as the root path and not duplicated as a constant.
Implementation
bool get isHome => routeName == 'home';
home is rendered as the root path and not duplicated as a constant.
bool get isHome => routeName == 'home';