kSkillFileName top-level constant

String const kSkillFileName

The bundled Claude Code skill, embedded as a string so river_cli skill can write it into a project regardless of how the CLI was installed.

Keep this in sync with the documentation in README.md.

Implementation

const String kSkillFileName = 'SKILL.md';